@@ -21,15 +21,15 @@
 The Documents menu.
 """
 
-from __future__ import unicode_literals
 
-from PyQt4.QtGui import QAction, QActionGroup, QIcon, QMenu
+from PyQt5.QtGui import QIcon
+from PyQt5.QtWidgets import QAction, QActionGroup, QMenu
 
 import app
 import icons
 import plugin
 import engrave
-import jobmanager
+import documenticon
 
 
 class DocumentMenu(QMenu):
@@ -48,7 +48,7 @@ class DocumentMenu(QMenu):
             self.addAction(a)
             
 
-class DocumentActionGroup(QActionGroup, plugin.MainWindowPlugin):
+class DocumentActionGroup(plugin.MainWindowPlugin, QActionGroup):
     """Maintains a list of actions to set the current document.
     
     The actions are added to the View->Documents menu in the order
@@ -57,7 +57,7 @@ class DocumentActionGroup(QActionGroup, plugin.MainWindowPlugin):
     
     """
     def __init__(self, mainwindow):
-        super(DocumentActionGroup, self).__init__(mainwindow)
+        QActionGroup.__init__(self, mainwindow)
         self._acts = {}
         self._accels = {}
         self.setExclusive(True)
@@ -108,12 +108,8 @@ class DocumentActionGroup(QActionGroup, plugin.MainWindowPlugin):
             # L10N: 'always engraved': the document is marked as 'Always Engrave' in the LilyPond menu
             name += " " + _("[always engraved]")
         self._acts[doc].setText(name)
-        # set the icon
-        if jobmanager.is_running(doc):
-            icon = icons.get('lilypond-run')
-        elif doc.isModified():
-            icon = icons.get('document-save')
-        else:
+        icon = documenticon.icon(doc, self.mainwindow())
+        if icon.name() == "text-plain":
             icon = QIcon()
         self._acts[doc].setIcon(icon)
     
