@@ -22,12 +22,12 @@ Exception dialog for unhandled Python exceptions
 (which are bugs in our program).
 """
 
-from __future__ import unicode_literals
 
 import traceback
 
-from PyQt4.QtGui import (
-    QDialog, QDialogButtonBox, QLabel, QTextBrowser, QTextCursor, QVBoxLayout)
+from PyQt5.QtGui import QTextCursor
+from PyQt5.QtWidgets import (
+    QDialog, QDialogButtonBox, QLabel, QTextBrowser, QVBoxLayout)
 
 import app
 import icons
