@@ -21,13 +21,12 @@
 The window displayed when a Document is modified by an external program.
 """
 
-from __future__ import unicode_literals
 
 import os
 
-from PyQt4.QtCore import QSize, Qt
-from PyQt4.QtGui import (QCheckBox, QGridLayout, QMessageBox, QPushButton,
-                         QTextBrowser, QTreeWidget, QTreeWidgetItem)
+from PyQt5.QtCore import QSize, Qt
+from PyQt5.QtWidgets import (QCheckBox, QGridLayout, QMessageBox, QPushButton,
+                             QTextBrowser, QTreeWidget, QTreeWidgetItem)
 
 import app
 import qutil
