@@ -21,14 +21,15 @@
 Export to non-lilypond file types.
 """
 
-from __future__ import unicode_literals
 
 import os
 
-from PyQt4.QtCore import Qt, QUrl, QSize
-from PyQt4.QtGui import QAction, QFileDialog, QKeySequence, QMessageBox
+from PyQt5.QtCore import Qt, QUrl, QSize
+from PyQt5.QtGui import QKeySequence
+from PyQt5.QtWidgets import QAction, QFileDialog, QMessageBox
 
 import app
+import icons
 import actioncollection
 import actioncollectionmanager
 import documentinfo
@@ -56,12 +57,12 @@ class FileExport(plugin.MainWindowPlugin):
         filename = os.path.splitext(orgname)[0] + '.xml'
         caption = app.caption(_("dialog title", "Export MusicXML File"))
         filetypes = '{0} (*.xml);;{1} (*)'.format(_("XML Files"), _("All Files"))
-        filename = QFileDialog.getSaveFileName(self.mainwindow(), caption, filename, filetypes)
+        filename = QFileDialog.getSaveFileName(self.mainwindow(), caption, filename, filetypes)[0]
         if not filename:
             return False # cancelled
         import ly.musicxml
         writer = ly.musicxml.writer()
-        writer.parse_text(doc.toPlainText())
+        writer.parse_text(doc.toPlainText(), orgname)
         xml = writer.musicxml()
         # put the Frescobaldi version in the xml file
         software = xml.root.find('.//encoding/software')
@@ -87,7 +88,7 @@ class FileExport(plugin.MainWindowPlugin):
         wavfile = os.path.splitext(orgname)[0] + '.wav'
         caption = app.caption(_("dialog title", "Export Audio File"))
         filetypes = '{0} (*.wav);;{1} (*)'.format(_("WAV Files"), _("All Files"))
-        wavfile = QFileDialog.getSaveFileName(mainwin, caption, wavfile, filetypes)
+        wavfile = QFileDialog.getSaveFileName(mainwin, caption, wavfile, filetypes)[0]
         if not wavfile:
             return False # cancelled
         dlg = AudioExportDialog(mainwin, caption)
@@ -129,6 +130,9 @@ class Actions(actioncollection.ActionCollection):
         self.export_musicxml = QAction(parent)
         self.export_audio = QAction(parent)
 
+        self.export_musicxml.setIcon(icons.get("document-export"))
+        self.export_audio.setIcon(icons.get("document-export"))
+
     def translateUI(self):
         self.export_musicxml.setText(_("Export Music&XML..."))
         self.export_musicxml.setToolTip(_("Export current document as MusicXML."))
