@@ -23,10 +23,9 @@ Uses musicxml2ly to create ly file from xml.
 In the dialog the options of musicxml2ly can be set. 
 """
 
-from __future__ import unicode_literals
 
-from PyQt4.QtCore import QSettings, QSize
-from PyQt4.QtGui import (QCheckBox, QComboBox, QDialogButtonBox, QLabel)
+from PyQt5.QtCore import QSettings, QSize
+from PyQt5.QtWidgets import (QCheckBox, QComboBox, QDialogButtonBox, QLabel)
 
 import app
 import qutil
@@ -139,7 +138,7 @@ class Dialog(toly_dialog.ToLyDialog):
         self.settings = QSettings()
         self.settings.beginGroup('musicxml_import')
         super(Dialog, self).loadSettings()
-        lang = self.settings.value("language", "default", type(""))
+        lang = self.settings.value("language", "default", str)
         try:
             index = _langlist.index(lang)
         except ValueError:
