@@ -21,15 +21,15 @@
 Helper application stuff.
 """
 
-from __future__ import unicode_literals
 
 import os
 import re
 import subprocess
 import sys
 
-from PyQt4.QtCore import QSettings
-from PyQt4.QtGui import QDesktopServices, QMessageBox
+from PyQt5.QtCore import QSettings
+from PyQt5.QtGui import QDesktopServices
+from PyQt5.QtWidgets import QMessageBox
 
 def shell_split(cmd):
     """Split a string like the UNIX shell, returning a list.
