@@ -22,24 +22,29 @@ Dialog for selecting a hyphen language,
 and code for finding hyphenation dictionaries to present the user a  choice.
 """
 
-from __future__ import unicode_literals
 
 import glob
 import locale
 import os
 
-from PyQt4.QtCore import QSettings, Qt
-from PyQt4.QtGui import QDialog, QDialogButtonBox, QLabel, QListWidget, QVBoxLayout
+from PyQt5.QtCore import QSettings, Qt
+from PyQt5.QtWidgets import QDialog, QDialogButtonBox, QLabel, QListWidget, QVBoxLayout
 
 import app
 import qutil
 import userguide
 import language_names
 import widgets
-import hyphdicts
 import hyphenator
 import po.setup
 
+# If the folder was completely removed by a distributor
+try:
+    import hyphdicts
+except ImportError:
+    hyphdicts = None
+
+
 # paths to check for hyphen dicts
 default_paths = [
     "share/hyphen",
@@ -67,14 +72,15 @@ def directories():
     
     def gen():
         # if the path is not absolute, add it to all prefixes.
-        paths = settings().value("paths", default_paths, type(""))
+        paths = settings().value("paths", default_paths, str)
         for path in paths:
             if os.path.isabs(path):
                 yield path
             else:
                 for pref in prefixes:
                     yield os.path.join(pref, path)
-        yield hyphdicts.path
+        if hyphdicts:
+            yield hyphdicts.path
     return filter(os.path.isdir, gen())
 
 def findDicts():
@@ -124,7 +130,7 @@ class HyphenDialog(QDialog):
             self.listWidget.addItem("{0}  ({1})".format(name, lang))
             
         def select():
-            lastused = settings().value("lastused", "", type(""))
+            lastused = settings().value("lastused", "", str)
             if lastused:
                 yield lastused
             lang = po.setup.preferred()[0]
