@@ -21,12 +21,12 @@
 Icons.
 """
 
-from __future__ import unicode_literals
 
 import os
 
-from PyQt4.QtCore import QDir, QFile, QFileInfo, QSettings, QSize
-from PyQt4.QtGui import QFileIconProvider, QIcon
+from PyQt5.QtCore import QDir, QFile, QFileInfo, QSettings, QSize
+from PyQt5.QtGui import QIcon
+from PyQt5.QtWidgets import QFileIconProvider
 
 import app
 
