@@ -21,13 +21,12 @@
 The Layout Control options widget.
 """
 
-from __future__ import unicode_literals
 
 import sys
 
-from PyQt4.QtCore import pyqtSignal, QSettings
-from PyQt4.QtGui import (QCheckBox, QHBoxLayout, QLineEdit, QToolButton,
-                         QVBoxLayout, QWidget)
+from PyQt5.QtCore import pyqtSignal, QSettings
+from PyQt5.QtWidgets import (QCheckBox, QHBoxLayout, QLineEdit, QToolButton,
+                             QVBoxLayout, QWidget)
 
 import app
 import icons
@@ -116,7 +115,7 @@ class Widget(QWidget):
         self.CBverbose.setChecked(s.value('verbose', False, bool))
         self.CBpointandclick.setChecked(s.value('point-and-click', True, bool))
         self.CBcustomfile.setChecked(s.value('custom-file', False, bool))
-        self.LEcustomfile.setText(s.value('custom-filename', '', type("")))
+        self.LEcustomfile.setText(s.value('custom-filename', '', str))
         
     def saveSettings(self):
         """Called on close. Save settings and checkboxes state."""
