@@ -16,7 +16,7 @@ TODO:
 import time
 import weakref
 
-from PyQt4.QtCore import QObject, QSettings, QThread, SIGNAL
+from PyQt5.QtCore import QObject, QSettings, QThread, pyqtSignal
 
 import midihub
 import midifile.event
@@ -42,12 +42,12 @@ class MidiIn(object):
     
     def open(self):
         s = QSettings()
-        self._portname = s.value("midi/input_port", midihub.default_input(), type(""))
+        self._portname = s.value("midi/midi/input_port", midihub.default_input(), str)
         self._pollingtime = s.value("midi/polling_time", 10, int)
         self._portmidiinput = midihub.input_by_name(self._portname)
         
         self._listener = Listener(self._portmidiinput, self._pollingtime)
-        QObject.connect(self._listener, SIGNAL("caughtevent"), self.analyzeevent)
+        self._listener.NoteEventSignal.connect(self.analyzeevent)
     
     def close(self):
         # self._portmidiinput.close()
@@ -83,7 +83,8 @@ class MidiIn(object):
     
     def noteevent(self, notetype, channel, notenumber, value):
         targetchannel = self.widget().channel()
-        if channel == targetchannel or targetchannel == 0:    # '0' captures all
+        if targetchannel == 0 or channel == targetchannel-1: # '0' captures all
+            # midi channels start at 1 for humans and 0 for programs
             if notetype == 9 and value > 0:    # note on with velocity > 0
                 notemapping = elements.NoteMapping(self.widget().keysignature(), self.widget().accidentals()=='sharps')
                 note = elements.Note(notenumber, notemapping)
@@ -113,6 +114,7 @@ class MidiIn(object):
             cursor.insertText(' ' +  text)
     
 class Listener(QThread):
+    NoteEventSignal = pyqtSignal(midifile.event.NoteEvent)
     def __init__(self, portmidiinput, pollingtime):
         QThread.__init__(self)
         self._portmidiinput = portmidiinput
@@ -136,7 +138,8 @@ class Listener(QThread):
             s = bytearray([77, data[0][0][0], data[0][0][1], data[0][0][2], data[0][0][3]])
             event = next(midifile.parser.parse_midi_events(s))[1]
             
-            self.emit(SIGNAL("caughtevent"), event)
+            if isinstance(event,midifile.event.NoteEvent):
+                self.NoteEventSignal.emit(event)
     
     def stop(self):
         self._capturing = False
