@@ -21,11 +21,10 @@
 Handles MIDI files.
 """
 
-from __future__ import unicode_literals
 
 import os
 
-from PyQt4.QtCore import Qt
+from PyQt5.QtCore import Qt
 
 import icons
 import plugin
@@ -57,8 +56,6 @@ class MidiFiles(plugin.DocumentPlugin):
     def __bool__(self):
         return bool(self._files)
     
-    __nonzero__ = __bool__      # py2 compat
-    
     def song(self, index):
         if self._files is None:
             self.update()
