@@ -21,10 +21,9 @@
 Shows the time position of the text cursor in the music.
 """
 
-from __future__ import unicode_literals
 
-from PyQt4.QtCore import QTimer
-from PyQt4.QtGui import QLabel
+from PyQt5.QtCore import QTimer
+from PyQt5.QtWidgets import QLabel
 
 import weakref
 
@@ -90,6 +89,7 @@ class MusicPosition(plugin.ViewSpacePlugin):
                 text = _("Pos: {pos}").format(
                     pos=ly.duration.format_fraction(pos)) if pos is not None else ''
             self._label.setText(text)
+            self._label.setVisible(bool(text))
 
 
 app.viewSpaceCreated.connect(MusicPosition.instance)
