@@ -21,10 +21,9 @@
 The PDF preview panel context menu.
 """
 
-from __future__ import unicode_literals
 
-from PyQt4.QtCore import QUrl
-from PyQt4.QtGui import QApplication, QMenu
+from PyQt5.QtCore import QUrl
+from PyQt5.QtWidgets import QApplication, QMenu
 
 
 import icons
@@ -35,7 +34,7 @@ def show(position, panel, link, cursor):
     
     position: The global position to pop up
     panel: The music view panel, giving access to mainwindow and view widget
-    link: a popplerqt4 LinkBrowse instance or None
+    link: a popplerqt5 LinkBrowse instance or None
     cursor: a QTextCursor instance or None
     
     """
@@ -43,13 +42,15 @@ def show(position, panel, link, cursor):
     
     # selection? -> Copy
     if panel.widget().view.surface().hasSelection():
+        if panel.widget().view.surface().selectedText():
+            m.addAction(panel.actionCollection.music_copy_text)
         m.addAction(panel.actionCollection.music_copy_image)
     
     if cursor:
         a = m.addAction(icons.get("document-edit"), _("Edit in Place"))
         @a.triggered.connect
         def edit():
-            from . import editinplace
+            import editinplace
             editinplace.edit(panel.widget(), cursor, position)
     elif link:
         a = m.addAction(icons.get("window-new"), _("Open Link in &New Window"))
