@@ -18,12 +18,11 @@
 # See http://www.gnu.org/licenses/ for more information.
 
 """
-A dummy surface only showing a "could not load popplerqt4 module" message.
+A dummy surface only showing a "could not load popplerqt5 module" message.
 """
 
-from __future__ import unicode_literals
 
-from PyQt4.QtGui import QLabel, QLayout, QVBoxLayout, QWidget
+from PyQt5.QtWidgets import QLabel, QLayout, QVBoxLayout, QWidget
 
 import qpopplerview
 import app
@@ -40,7 +39,7 @@ class Surface(qpopplerview.Surface):
     
     def translateUI(self):
         self._msg.setText(_("Could not load the {name} module.").format(
-            name = '<a href="https://github.com/wbsoft/python-poppler-qt4">popplerqt4</a>'))
+            name = '<a href="https://github.com/wbsoft/python-poppler-qt4">popplerqt5</a>'))
     
     def paintEvent(self, ev):
         QWidget.paintEvent(self, ev)
