@@ -21,14 +21,13 @@
 The Preferences Dialog.
 """
 
-from __future__ import unicode_literals
 
 
-from PyQt4.QtCore import QSettings, QSize, Qt, pyqtSignal
-from PyQt4.QtGui import (
-    QDialog, QDialogButtonBox, QGroupBox, QHBoxLayout, QKeySequence,
-    QListWidget, QListWidgetItem, QScrollArea, QStackedWidget, QVBoxLayout,
-    QWidget)
+from PyQt5.QtCore import QSettings, QSize, Qt, pyqtSignal
+from PyQt5.QtGui import QKeySequence
+from PyQt5.QtWidgets import (
+    QDialog, QDialogButtonBox, QGroupBox, QHBoxLayout, QListWidget,
+    QListWidgetItem, QScrollArea, QStackedWidget, QVBoxLayout, QWidget)
 
 import app
 import qutil
