@@ -21,19 +21,14 @@
 Fonts and Colors preferences page.
 """
 
-from __future__ import unicode_literals
 
-from PyQt4.QtCore import pyqtSignal, QSettings, QSize, Qt
-from PyQt4.QtGui import (QApplication, QBrush, QCheckBox, QColor,
-                         QDoubleSpinBox, QFont, QFontComboBox, QGridLayout,
-                         QGroupBox, QHBoxLayout, QLabel, QMessageBox, QPalette,
-                         QStackedWidget, QTextCharFormat, QTextFormat,
-                         QTreeWidget, QTreeWidgetItem, QVBoxLayout, QWidget)
-
-try:
-    str = unicode
-except NameError:
-    pass
+from PyQt5.QtCore import pyqtSignal, QSettings, QSize, Qt
+from PyQt5.QtGui import (QBrush, QColor, QFont, QPalette, QTextCharFormat,
+                         QTextFormat)
+from PyQt5.QtWidgets import (QApplication, QCheckBox, QDoubleSpinBox,
+                             QFontComboBox, QGridLayout, QGroupBox,
+                             QHBoxLayout, QLabel, QMessageBox, QStackedWidget,
+                             QTreeWidget, QTreeWidgetItem, QVBoxLayout, QWidget)
 
 import app
 import icons
@@ -140,9 +135,17 @@ class FontsColors(preferences.Page):
         for name in textformats.defaultStyles:
             self.defaultStyles[name].setText(0, self.defaultStyleNames[name])
         for group, styles in ly.colorize.default_mapping():
-            self.allStyles[group][0].setText(0, self.allStyleNames[group][0])
+            try:
+                n = self.allStyleNames[group][0]
+            except KeyError:
+                n = group
+            self.allStyles[group][0].setText(0, n)
             for name, base, clss in styles:
-                self.allStyles[group][1][name].setText(0, self.allStyleNames[group][1][name])
+                try:
+                    n = self.allStyleNames[group][1][name]
+                except KeyError:
+                    n = name
+                self.allStyles[group][1][name].setText(0, n)
             
     def currentItemChanged(self, item, previous):
         if item is self.baseColorsItem:
@@ -284,7 +287,7 @@ class FontsColors(preferences.Page):
     
     def loadSettings(self):
         self.data = {} # holds all data with scheme as key
-        self._printScheme = QSettings().value("printer_scheme", "default", type(""))
+        self._printScheme = QSettings().value("printer_scheme", "default", str)
         self.scheme.loadSettings("editor_scheme", "editor_schemes")
         
     def saveSettings(self):
