@@ -21,11 +21,10 @@
 Keyboard shortcuts settings page.
 """
 
-from __future__ import unicode_literals
 
-from PyQt4.QtCore import QSettings
-from PyQt4.QtGui import (QCheckBox, QComboBox, QGridLayout, QHBoxLayout, QLabel,
-                         QRadioButton, QStyleFactory, QVBoxLayout)
+from PyQt5.QtCore import QSettings
+from PyQt5.QtWidgets import (QCheckBox, QComboBox, QGridLayout, QHBoxLayout,
+                             QLabel, QRadioButton, QStyleFactory, QVBoxLayout)
 
 import app
 import appinfo
@@ -73,10 +72,12 @@ class General(preferences.Group):
         
         self.systemIcons = QCheckBox(toggled=self.changed)
         grid.addWidget(self.systemIcons, 2, 0, 1, 3)
+        self.tabsClosable = QCheckBox(toggled=self.changed)
+        grid.addWidget(self.tabsClosable, 3, 0, 1, 3)
         self.splashScreen = QCheckBox(toggled=self.changed)
-        grid.addWidget(self.splashScreen, 3, 0, 1, 3)
+        grid.addWidget(self.splashScreen, 4, 0, 1, 3)
         self.allowRemote = QCheckBox(toggled=self.changed)
-        grid.addWidget(self.allowRemote, 4, 0, 1, 3)
+        grid.addWidget(self.allowRemote, 5, 0, 1, 3)
         
         grid.setColumnStretch(2, 1)
         
@@ -97,13 +98,13 @@ class General(preferences.Group):
     
     def loadSettings(self):
         s = QSettings()
-        lang = s.value("language", "", type(""))
+        lang = s.value("language", "", str)
         try:
             index = self._langs.index(lang)
         except ValueError:
             index = 1
         self.lang.setCurrentIndex(index)
-        style = s.value("guistyle", "", type("")).lower()
+        style = s.value("guistyle", "", str).lower()
         styles = [name.lower() for name in QStyleFactory.keys()]
         try:
             index = styles.index(style) + 1
@@ -111,6 +112,7 @@ class General(preferences.Group):
             index = 0
         self.styleCombo.setCurrentIndex(index)
         self.systemIcons.setChecked(s.value("system_icons", True, bool))
+        self.tabsClosable.setChecked(s.value("tabs_closable", True, bool))
         self.splashScreen.setChecked(s.value("splash_screen", True, bool))
         self.allowRemote.setChecked(remote.enabled())
     
@@ -118,6 +120,7 @@ class General(preferences.Group):
         s = QSettings()
         s.setValue("language", self._langs[self.lang.currentIndex()])
         s.setValue("system_icons", self.systemIcons.isChecked())
+        s.setValue("tabs_closable", self.tabsClosable.isChecked())
         s.setValue("splash_screen", self.splashScreen.isChecked())
         s.setValue("allow_remote", self.allowRemote.isChecked())
         if self.styleCombo.currentIndex() == 0:
@@ -138,6 +141,7 @@ class General(preferences.Group):
             "will be used instead of the bundled icons.\n"
             "This setting takes effect on the next start of {appname}.").format(appname=appinfo.appname))
         self.splashScreen.setText(_("Show Splash Screen on Startup"))
+        self.tabsClosable.setText(_("Show Close Button on Document tabs"))
         self.allowRemote.setText(_("Open Files in Running Instance"))
         self.allowRemote.setToolTip(_(
             "If checked, files will be opened in a running Frescobaldi "
@@ -176,7 +180,7 @@ class StartSession(preferences.Group):
     def loadSettings(self):
         s = QSettings()
         s.beginGroup("session")
-        startup = s.value("startup", "none", type(""))
+        startup = s.value("startup", "none", str)
         if startup ==  "lastused":
             self.lastused.setChecked(True)
         elif startup == "custom":
@@ -186,7 +190,7 @@ class StartSession(preferences.Group):
         sessionNames = sessions.sessionNames()
         self.combo.clear()
         self.combo.addItems(sessionNames)
-        custom = s.value("custom", "", type(""))
+        custom = s.value("custom", "", str)
         if custom in sessionNames:
             self.combo.setCurrentIndex(sessionNames.index(custom))
 
@@ -247,7 +251,7 @@ class SavingDocument(preferences.Group):
         self.stripwsp.setChecked(s.value("strip_trailing_whitespace", False, bool))
         self.backup.setChecked(s.value("backup_keep", False, bool))
         self.metainfo.setChecked(s.value("metainfo", True, bool))
-        self.basedir.setPath(s.value("basedir", "", type("")))
+        self.basedir.setPath(s.value("basedir", "", str))
         
     def saveSettings(self):
         s = QSettings()
@@ -298,8 +302,8 @@ class NewDocument(preferences.Group):
         
     def loadSettings(self):
         s = QSettings()
-        ndoc = s.value("new_document", "empty", type(""))
-        template = s.value("new_document_template", "", type(""))
+        ndoc = s.value("new_document", "empty", str)
+        template = s.value("new_document_template", "", str)
         if template in self._names:
             self.combo.setCurrentIndex(self._names.index(template))
         if ndoc == "template":
