@@ -21,15 +21,16 @@
 A widget that provides a scheme selector, with New and Remove buttons.
 """
 
-from __future__ import unicode_literals
 
 try:
     import xml.etree.cElementTree as ET
 except ImportError:
     import xml.etree.ElementTree as ET
 
-from PyQt4.QtGui import (QTextFormat, QMessageBox, QColor, QTextCharFormat,
-                         QFont, QFontDatabase, QKeySequence)
+from PyQt5.QtGui import (
+    QTextFormat, QColor, QTextCharFormat, QFont, QFontDatabase,
+    QKeySequence)
+from PyQt5.QtWidgets import QMessageBox
 
 import os
 import appinfo
