@@ -21,11 +21,11 @@
 MIDI preferences.
 """
 
-from __future__ import unicode_literals
 
-from PyQt4.QtCore import QSettings
-from PyQt4.QtGui import (QCheckBox, QComboBox, QGridLayout, QHBoxLayout, QLabel,
-                         QPushButton, QSpinBox, QVBoxLayout)
+from PyQt5.QtCore import QSettings
+from PyQt5.QtWidgets import (
+    QCheckBox, QComboBox, QGridLayout, QHBoxLayout, QLabel, QPushButton,
+    QSpinBox, QVBoxLayout)
 
 
 import app
@@ -133,8 +133,8 @@ class MidiPorts(preferences.Group):
         input_port = midihub.default_input()
         s = QSettings()
         s.beginGroup("midi")
-        self._playerPort.setEditText(s.value("player/output_port", output_port, type("")))
-        self._inputPort.setEditText(s.value("midi/input_port", input_port, type("")))
+        self._playerPort.setEditText(s.value("player/output_port", output_port, str))
+        self._inputPort.setEditText(s.value("midi/input_port", input_port, str))
         
     def saveSettings(self):
         s = QSettings()
