@@ -21,19 +21,18 @@
 The Quick Insert panel widget.
 """
 
-from __future__ import unicode_literals
 
 import weakref
 
-from PyQt4.QtCore import QSettings
-from PyQt4.QtGui import (QComboBox, QHBoxLayout, QLabel, QToolBox, QToolButton,
-                         QVBoxLayout, QWidget)
+from PyQt5.QtCore import QSettings
+from PyQt5.QtWidgets import (QComboBox, QHBoxLayout, QLabel, QToolBox,
+                             QToolButton, QVBoxLayout, QWidget)
 
 import app
 import userguide.util
 import icons
 import symbols
-import widgets.toolboxwheeler
+import gadgets.toolboxwheeler
 
 from . import articulations
 from . import barlines
@@ -70,7 +69,7 @@ class QuickInsert(QWidget):
         layout.addLayout(hor)
         
         self.toolbox = QToolBox(self)
-        widgets.toolboxwheeler.ToolBoxWheeler(self.toolbox)
+        gadgets.toolboxwheeler.ToolBoxWheeler(self.toolbox)
         layout.addWidget(self.toolbox)
         
         for cls in (
@@ -86,7 +85,7 @@ class QuickInsert(QWidget):
         userguide.openWhatsThis(self)
         
         # restore remembered current page
-        name = QSettings().value("quickinsert/current_tool", "", type(""))
+        name = QSettings().value("quickinsert/current_tool", "", str)
         if name:
             for i in range(self.toolbox.count()):
                 if name == self.toolbox.widget(i).__class__.__name__.lower():
