@@ -21,12 +21,11 @@
 Container part types.
 """
 
-from __future__ import unicode_literals
 
-from PyQt4.QtCore import QSize
-from PyQt4.QtGui import (QCheckBox, QComboBox, QGridLayout, QGroupBox,
-                         QHBoxLayout, QLabel, QLineEdit, QRadioButton,
-                         QVBoxLayout)
+from PyQt5.QtCore import QSize
+from PyQt5.QtWidgets import (QCheckBox, QComboBox, QGridLayout, QGroupBox,
+                             QHBoxLayout, QLabel, QLineEdit, QRadioButton,
+                             QVBoxLayout)
 
 import ly.dom
 import listmodel
