@@ -21,11 +21,10 @@
 The score settings widget.
 """
 
-from __future__ import unicode_literals
 
-from PyQt4.QtCore import QSettings
-from PyQt4.QtGui import (QCheckBox, QComboBox, QGridLayout, QGroupBox,
-                         QHBoxLayout, QLabel, QVBoxLayout, QWidget)
+from PyQt5.QtCore import QSettings
+from PyQt5.QtWidgets import (QCheckBox, QComboBox, QGridLayout, QGroupBox,
+                             QHBoxLayout, QLabel, QVBoxLayout, QWidget)
 
 import app
 import po.setup
@@ -73,11 +72,23 @@ class ScoreProperties(QGroupBox, scoreproperties.ScoreProperties):
         scorewiz = self.window()
         scorewiz.pitchLanguageChanged.connect(self.setPitchLanguage)
         self.setPitchLanguage(scorewiz.pitchLanguage())
+
+        self.loadSettings()
+        self.window().finished.connect(self.saveSettings)
         
     def translateUI(self):
         self.translateWidgets()
         self.setTitle(_("Score properties"))
-    
+
+    def loadSettings(self):
+        s = QSettings()
+        s.beginGroup('scorewiz/scoreproperties')
+        self.metronomeRound.setChecked(s.value('round_metronome', True, bool))
+
+    def saveSettings(self):
+        s = QSettings()
+        s.beginGroup('scorewiz/scoreproperties')
+        s.setValue('round_metronome', self.metronomeRound.isChecked())
 
 
 class GeneralPreferences(QGroupBox):
@@ -160,7 +171,7 @@ class GeneralPreferences(QGroupBox):
         self.neutdir.setChecked(s.value('smart_neutral_direction', False, bool))
         self.midi.setChecked(s.value('midi', True, bool))
         self.metro.setChecked(s.value('metronome_mark', False, bool))
-        psize = s.value('paper_size', '', type(""))
+        psize = s.value('paper_size', '', str)
         enable = bool(psize and psize in paperSizes)
         self.paper.setCurrentIndex(paperSizes.index(psize) if enable else 0)
         self.paperLandscape.setChecked(s.value('paper_landscape', False, bool))
@@ -253,12 +264,12 @@ class InstrumentNames(QGroupBox):
         s.beginGroup('scorewiz/instrumentnames')
         self.setChecked(s.value('enabled', True, bool))
         allow = ['long', 'short']
-        first = s.value('first', '', type(""))
+        first = s.value('first', '', str)
         self.firstSystem.setCurrentIndex(allow.index(first) if first in allow else 0)
         allow = ['long', 'short', 'none']
-        other = s.value('other', '', type(""))
+        other = s.value('other', '', str)
         self.otherSystems.setCurrentIndex(allow.index(other) if other in allow else 2)
-        language = s.value('language', '', type(""))
+        language = s.value('language', '', str)
         self.language.setCurrentIndex(self._langs.index(language) if language in self._langs else 0)
     
     def saveSettings(self):
