@@ -21,16 +21,11 @@
 Highlighter for the snippet editor and view.
 """
 
-from __future__ import unicode_literals
-
-try:
-    import builtins # py3
-except ImportError:
-    import __builtin__ as builtins # py2
 
+import builtins
 import keyword
 
-from PyQt4.QtGui import QSyntaxHighlighter
+from PyQt5.QtGui import QSyntaxHighlighter
 
 import app
 import textformats
