@@ -21,11 +21,10 @@
 Restored changed or deleted builtin snippets.
 """
 
-from __future__ import unicode_literals
 
 
-from PyQt4.QtCore import Qt
-from PyQt4.QtGui import QTreeWidget, QTreeWidgetItem
+from PyQt5.QtCore import Qt
+from PyQt5.QtWidgets import QTreeWidget, QTreeWidgetItem
 
 import app
 import userguide
