@@ -21,12 +21,12 @@
 The snippets dockwindow.
 """
 
-from __future__ import unicode_literals
 
 import weakref
 
-from PyQt4.QtCore import Qt
-from PyQt4.QtGui import QAction, QKeySequence
+from PyQt5.QtCore import Qt
+from PyQt5.QtGui import QKeySequence
+from PyQt5.QtWidgets import QAction
 
 import actioncollection
 import actioncollectionmanager
@@ -133,6 +133,8 @@ class SnippetActions(actioncollection.ShortcutCollection):
         self.setDefaultShortcuts('lowercase', [QKeySequence('Ctrl+Shift+U')])
         self.setDefaultShortcuts('last_note', [QKeySequence('Ctrl+;')])
         self.setDefaultShortcuts('double', [QKeySequence('Ctrl+D')])
+        self.setDefaultShortcuts('comment', [QKeySequence('Ctrl+Alt+C, Ctrl+Alt+C')])
+        self.setDefaultShortcuts('uncomment', [QKeySequence('Ctrl+Alt+C, Ctrl+Alt+U')])
         
     def realAction(self, name):
         from . import actions, model
