@@ -21,13 +21,13 @@
 The snippets widget.
 """
 
-from __future__ import unicode_literals
 
-from PyQt4.QtCore import QEvent, QModelIndex, Qt
-from PyQt4.QtGui import (QAction, QApplication, QCompleter, QFileDialog,
-                         QHBoxLayout, QItemSelectionModel, QKeySequence, QMenu,
-                         QMessageBox, QPushButton, QSplitter, QTextBrowser,
-                         QToolButton, QTreeView, QVBoxLayout, QWidget)
+from PyQt5.QtCore import QEvent, QItemSelectionModel, QModelIndex, Qt
+from PyQt5.QtGui import QKeySequence
+from PyQt5.QtWidgets import (
+    QAction, QApplication, QCompleter, QFileDialog, QHBoxLayout, QMenu,
+    QMessageBox, QPushButton, QSplitter, QTextBrowser, QToolButton,
+    QTreeView, QVBoxLayout, QWidget)
 
 import app
 import userguide
@@ -300,7 +300,7 @@ class Widget(QWidget):
         filetypes = "{0} (*.xml);;{1} (*)".format(_("XML Files"), _("All Files"))
         caption = app.caption(_("dialog title", "Import Snippets"))
         filename = None
-        filename = QFileDialog.getOpenFileName(self, caption, filename, filetypes)
+        filename = QFileDialog.getOpenFileName(self, caption, filename, filetypes)[0]
         if filename:
             from . import import_export
             import_export.load(filename, self)
@@ -318,7 +318,7 @@ class Widget(QWidget):
         n = len(names)
         caption = app.caption(_("dialog title",
             "Export {num} Snippet", "Export {num} Snippets", n).format(num=n))
-        filename = QFileDialog.getSaveFileName(self, caption, None, filetypes)
+        filename = QFileDialog.getSaveFileName(self, caption, None, filetypes)[0]
         if filename:
             from . import import_export
             try:
