@@ -21,11 +21,10 @@
 Handles SVG files.
 """
 
-from __future__ import unicode_literals
 
 import os
 
-from PyQt4.QtCore import Qt, QUrl
+from PyQt5.QtCore import Qt, QUrl
 
 import icons
 import plugin
@@ -55,8 +54,6 @@ class SvgFiles(plugin.DocumentPlugin):
     def __bool__(self):
         return bool(self._files)
     
-    __nonzero__ = __bool__ # py2 compat
-    
     def model(self):
         """Returns a model for a combobox."""
         if self._files is None:
