@@ -24,19 +24,12 @@ When a character is clicked, a signal is emitted.
 
 """
 
-from __future__ import unicode_literals
-
-try:
-    chr = unichr
-    str = unicode
-except NameError:
-    pass
 
 import unicodedata
 
-from PyQt4.QtCore import pyqtSignal, QEvent, QRect, QSize, Qt
-from PyQt4.QtGui import (QFont, QFontMetrics, QPainter, QPalette, QPen,
-                         QToolTip, QWhatsThis, QWidget)
+from PyQt5.QtCore import pyqtSignal, QEvent, QRect, QSize, Qt
+from PyQt5.QtGui import QFont, QFontMetrics, QPainter, QPalette, QPen
+from PyQt5.QtWidgets import QToolTip, QWhatsThis, QWidget
 
 
 class CharMap(QWidget):
@@ -138,7 +131,7 @@ class CharMap(QWidget):
         selected_tile.setAlpha(96)
         selected_box = self.palette().color(QPalette.Highlight)
         
-        text_pen = QPen(self.palette().text())
+        text_pen = QPen(self.palette().text().color())
         disabled_pen = QPen(self.palette().color(QPalette.Disabled, QPalette.Text))
         selection_pen = QPen(selected_box)
         for row in rows:
