@@ -23,10 +23,9 @@ Provides a QTextEdit subclass that grows vertically to accommodate document size
 You should set maximumHeight to restrict its vertical size.
 """
 
-from __future__ import unicode_literals
 
-from PyQt4.QtCore import QSize, Qt
-from PyQt4.QtGui import QPlainTextEdit, QStyle, QTextEdit
+from PyQt5.QtCore import QSize, Qt
+from PyQt5.QtWidgets import QPlainTextEdit, QStyle, QTextEdit
 
 
 __all__ = ["GrowingPlainTextEdit", "GrowingTextEdit"]
