@@ -24,11 +24,11 @@ Loosely based on kkeysequencewidget.cpp from KDE :-)
 
 """
 
-from __future__ import unicode_literals
 
-from PyQt4.QtCore import QEvent, QSize, Qt, QTimer, pyqtSignal
-from PyQt4.QtGui import (
-    QApplication, QHBoxLayout, QKeySequence, QPushButton, QToolButton, QWidget)
+from PyQt5.QtCore import QEvent, QSize, Qt, QTimer, pyqtSignal
+from PyQt5.QtGui import QKeySequence
+from PyQt5.QtWidgets import (
+    QApplication, QHBoxLayout, QPushButton, QToolButton, QWidget)
 
 import app
 import icons
