@@ -99,7 +99,7 @@ APPBUNDLE=dist/Frescobaldi.app
 
 echo Copying libqsvg.dylib inside the .app bundle.
 echo
-cp ${MPPREFIX}/share/qt4/plugins/imageformats/libqsvg.dylib ${APPBUNDLE}/Contents/PlugIns/imageformats/
+cp ${MPPREFIX}/libexec/qt4/share/plugins/imageformats/libqsvg.dylib ${APPBUNDLE}/Contents/PlugIns/imageformats/
 
 echo Finalizing the .app bundle with macdeployqt.
 echo \(This step will likely give an error about the failed copy of libqsvg.dylib:
@@ -108,7 +108,7 @@ echo
 # The expected error is:
 # ERROR: file copy failed from "${MPPREFIX}/share/qt4/plugins/imageformats/libqsvg.dylib" 
 # ERROR:  to "dist/Frescobaldi.app/Contents/PlugIns/imageformats/libqsvg.dylib" 
-${MPPREFIX}/bin/macdeployqt ${APPBUNDLE}
+${MPPREFIX}/libexec/qt4/bin/macdeployqt ${APPBUNDLE}
 echo
 
 MACHO=`find ${APPBUNDLE} -type f -exec file {} + | grep Mach-O`
